@@ -20,7 +20,7 @@ use base qw( Exporter );
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 our @aliens;
@@ -145,6 +145,9 @@ sub xs_ok
   }
   
   $xs = { xs => $xs } unless ref $xs;
+  # make sure this is a copy because we may
+  # modify it.
+  $xs->{xs} = "@{[ $xs->{xs} ]}";
   $xs->{pxs} ||= {};
   my $verbose = $xs->{verbose};
   my $ok = 1;
@@ -245,16 +248,20 @@ sub xs_ok
     if($ok)
     {
     
-      my($out, $lib) = capture_merged {
-        $cb->link(
-          objects            => [$obj],
-          module_name        => $module,
-          extra_linker_flags => [shellwords map { $_->libs } @aliens],
-        );
+      my($out, $lib, $err) = capture_merged {
+        my $lib = eval { 
+          $cb->link(
+            objects            => [$obj],
+            module_name        => $module,
+            extra_linker_flags => [shellwords map { $_->libs } @aliens],
+          );
+        };
+        ($lib, $@);
       };
       
       $ctx->note("link $obj") if $verbose;
       $ctx->note($out) if $verbose;
+      $ctx->note($err) if $verbose && $err;
       
       if($lib)
       {
@@ -264,6 +271,7 @@ sub xs_ok
       {
         $ok = 0;
         push @diag, '  ExtUtils::CBuilder->link failed';
+        push @diag, "    $err" if $err;
         push @diag, "    $_" for split /\r?\n/, $out;
       }
       
@@ -433,7 +441,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
